@@ -13,6 +13,7 @@ struct _Demo
 GtkWidget *do_appwindow (GtkWidget *do_widget);
 GtkWidget *do_button_box (GtkWidget *do_widget);
 GtkWidget *do_changedisplay (GtkWidget *do_widget);
+GtkWidget *do_clipboard (GtkWidget *do_widget);
 GtkWidget *do_colorsel (GtkWidget *do_widget);
 GtkWidget *do_dialog (GtkWidget *do_widget);
 GtkWidget *do_drawingarea (GtkWidget *do_widget);
@@ -49,6 +50,7 @@ Demo testgtk_demos[] = {
   { "Application main window", "appwindow.c", do_appwindow, NULL }, 
   { "Button Boxes", "button_box.c", do_button_box, NULL }, 
   { "Change Display", "changedisplay.c", do_changedisplay, NULL }, 
+  { "Clipboard", "clipboard.c", do_clipboard, NULL }, 
   { "Color Selector", "colorsel.c", do_colorsel, NULL }, 
   { "Dialog and Message Boxes", "dialog.c", do_dialog, NULL }, 
   { "Drawing Area", "drawingarea.c", do_drawingarea, NULL }, 
