@@ -3,6 +3,7 @@
  * Dialog widgets are used to pop up a transient window for user feedback.
  */
 
+#include <config.h>
 #include <gtk/gtk.h>
 
 static GtkWidget *window = NULL;
@@ -93,7 +94,7 @@ interactive_dialog_clicked (GtkButton *button,
 }
 
 GtkWidget *
-do_dialog (void)
+do_dialog (GtkWidget *do_widget)
 {
   GtkWidget *frame;
   GtkWidget *vbox;
@@ -106,6 +107,8 @@ do_dialog (void)
   if (!window)
     {
       window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+      gtk_window_set_screen (GTK_WINDOW (window),
+			     gtk_widget_get_screen (do_widget));
       gtk_window_set_title (GTK_WINDOW (window), "Dialogs");
 
       g_signal_connect (window, "destroy", G_CALLBACK (gtk_widget_destroyed), &window);
