@@ -159,6 +159,7 @@ static HKL latin_locale = NULL;
 #endif
 
 static gboolean in_ime_composition = FALSE;
+static gboolean resizing = FALSE;
 static UINT     resize_timer;
 
 static int debug_indent = 0;
@@ -2053,18 +2054,10 @@ resize_timer_proc (HWND     hwnd,
 		   UINT     id,
 		   DWORD    time)
 {
-  if (_sizemove_in_progress)
+  if (resizing)
     handle_stuff_while_moving_or_resizing ();
 }
 
-static void
-handle_display_change (void)
-{
-  _gdk_monitor_init ();
-  _gdk_root_window_size_init ();
-  g_signal_emit_by_name (_gdk_screen, "size_changed");
-}
-
 static gboolean
 gdk_event_translate (GdkDisplay *display,
 		     MSG        *msg,
@@ -2144,7 +2137,6 @@ gdk_event_translate (GdkDisplay *display,
 	  PostMessage (msg->hwnd, msg->message,
 		       msg->wParam, msg->lParam);
 	}
-#ifndef WITHOUT_WM_CREATE
       else if (msg->message == WM_CREATE)
 	{
 	  window = (UNALIGNED GdkWindow*) (((LPCREATESTRUCT) msg->lParam)->lpCreateParams);
@@ -2154,7 +2146,6 @@ gdk_event_translate (GdkDisplay *display,
 	{
 	  GDK_NOTE (EVENTS, g_print (" (no GdkWindow)"));
 	}
-#endif
       return FALSE;
     }
   
@@ -2975,12 +2966,12 @@ gdk_event_translate (GdkDisplay *display,
       break;
 
     case WM_ENTERSIZEMOVE:
-      _sizemove_in_progress = TRUE;
+      resizing = TRUE;
       resize_timer = SetTimer (NULL, 0, 20, resize_timer_proc);
       break;
 
     case WM_EXITSIZEMOVE:
-      _sizemove_in_progress = FALSE;
+      resizing = FALSE;
       KillTimer (NULL, resize_timer);
       break;
 
@@ -2988,7 +2979,7 @@ gdk_event_translate (GdkDisplay *display,
       /* Once we've entered the moving or sizing modal loop, we won't
        * return to the main loop until we're done sizing or moving.
        */
-      if (_sizemove_in_progress &&
+      if (resizing &&
 	 GDK_WINDOW_TYPE (window) != GDK_WINDOW_CHILD &&
 	 !GDK_WINDOW_DESTROYED (window))
 	{
@@ -3285,11 +3276,6 @@ gdk_event_translate (GdkDisplay *display,
       return_val = TRUE;
       break;
 
-    case WM_DISPLAYCHANGE:
-      handle_display_change ();
-      break;
-      
-
 #ifdef HAVE_WINTAB
       /* Handle WINTAB events here, as we know that gdkinput.c will
        * use the fixed WT_DEFBASE as lcMsgBase, and we thus can use the
