@@ -26,6 +26,7 @@
 
 #include <config.h>
 
+#include "gdkalias.h"
 #include "gdk.h"
 #include "gdkprivate-x11.h"
 #include "gdkinternals.h"
@@ -46,6 +47,14 @@
 #include <X11/XKBlib.h>
 #endif
 
+#ifdef HAVE_XSYNC
+#include <X11/extensions/sync.h>
+#endif
+
+#ifdef HAVE_XFIXES
+#include <X11/extensions/Xfixes.h>
+#endif
+
 #include <X11/Xatom.h>
 
 typedef struct _GdkIOClosure GdkIOClosure;
@@ -211,11 +220,10 @@ _gdk_events_init (GdkDisplay *display)
 
   display_sources = g_list_prepend (display_sources,display_source);
 
-  gdk_display_add_client_message_filter (
-	display,
-	gdk_atom_intern ("WM_PROTOCOLS", FALSE), 
-	gdk_wm_protocols_filter,   
-	NULL);
+  gdk_display_add_client_message_filter (display,
+					 gdk_atom_intern ("WM_PROTOCOLS", FALSE), 
+					 gdk_wm_protocols_filter,   
+					 NULL);
 }
 
 
@@ -821,8 +829,8 @@ set_user_time (GdkWindow *window,
    * to update the latest user interaction time.
    */
   if (gdk_event_get_time (event) != GDK_CURRENT_TIME)
-    _gdk_x11_window_set_user_time (gdk_window_get_toplevel (window),
-				   gdk_event_get_time (event));
+    gdk_x11_window_set_user_time (gdk_window_get_toplevel (window),
+                                  gdk_event_get_time (event));
 }
 
 static gboolean
@@ -1725,8 +1733,16 @@ gdk_event_translate (GdkDisplay *display,
 	  !GDK_WINDOW_DESTROYED (window) &&
 	  (window_private->extension_events != 0))
 	_gdk_input_configure_event (&xevent->xconfigure, window);
+      
+#ifdef HAVE_XSYNC
+      if (toplevel && display_x11->use_sync && !XSyncValueIsZero (toplevel->pending_counter_value))
+	{
+	  toplevel->current_counter_value = toplevel->pending_counter_value;
+	  XSyncIntToValue (&toplevel->pending_counter_value, 0);
+	}
+#endif
 
-      if (!window ||
+    if (!window ||
 	  xevent->xconfigure.event != xevent->xconfigure.window ||
           GDK_WINDOW_TYPE (window) == GDK_WINDOW_CHILD ||
           GDK_WINDOW_TYPE (window) == GDK_WINDOW_ROOT)
@@ -1960,6 +1976,24 @@ gdk_event_translate (GdkDisplay *display,
 	    }
 	}
       else
+#endif
+#ifdef HAVE_XFIXES
+      if (xevent->type - display_x11->xfixes_event_base == XFixesSelectionNotify)
+	{
+	  XFixesSelectionNotifyEvent *selection_notify = (XFixesSelectionNotifyEvent *)xevent;
+	  event->owner_change.type = GDK_OWNER_CHANGE;
+	  event->owner_change.window = window;
+	  event->owner_change.owner = selection_notify->owner;
+	  event->owner_change.reason = selection_notify->subtype;
+	  event->owner_change.selection = 
+	    gdk_x11_xatom_to_atom_for_display (display, 
+					       selection_notify->selection);
+	  event->owner_change.time = selection_notify->timestamp;
+	  event->owner_change.selection_time = selection_notify->selection_timestamp;
+
+	  return_val = TRUE;
+	}
+      else
 #endif
 	{
 	  /* something else - (e.g., a Xinput event) */
@@ -2006,8 +2040,9 @@ gdk_wm_protocols_filter (GdkXEvent *xev,
   XEvent *xevent = (XEvent *)xev;
   GdkWindow *win = event->any.window;
   GdkDisplay *display = GDK_WINDOW_DISPLAY (win);
+  Atom atom = (Atom)xevent->xclient.data.l[0];
 
-  if ((Atom) xevent->xclient.data.l[0] == gdk_x11_get_xatom_by_name_for_display (display, "WM_DELETE_WINDOW"))
+  if (atom == gdk_x11_get_xatom_by_name_for_display (display, "WM_DELETE_WINDOW"))
     {
   /* The delete window request specifies a window
    *  to delete. We don't actually destroy the
@@ -2025,7 +2060,7 @@ gdk_wm_protocols_filter (GdkXEvent *xev,
 
       return GDK_FILTER_TRANSLATE;
     }
-  else if ((Atom) xevent->xclient.data.l[0] == gdk_x11_get_xatom_by_name_for_display (display, "WM_TAKE_FOCUS"))
+  else if (atom == gdk_x11_get_xatom_by_name_for_display (display, "WM_TAKE_FOCUS"))
     {
       GdkToplevelX11 *toplevel = _gdk_x11_window_get_toplevel (event->any.window);
       GdkWindowObject *private = (GdkWindowObject *)win;
@@ -2040,7 +2075,7 @@ gdk_wm_protocols_filter (GdkXEvent *xev,
 
       return GDK_FILTER_REMOVE;
     }
-  else if ((Atom) xevent->xclient.data.l[0] == gdk_x11_get_xatom_by_name_for_display (display, "_NET_WM_PING") &&
+  else if (atom == gdk_x11_get_xatom_by_name_for_display (display, "_NET_WM_PING") &&
 	   !_gdk_x11_display_is_root_window (display,
 					     xevent->xclient.window))
     {
@@ -2054,7 +2089,21 @@ gdk_wm_protocols_filter (GdkXEvent *xev,
 
       return GDK_FILTER_REMOVE;
     }
-
+  else if (atom == gdk_x11_get_xatom_by_name_for_display (display, "_NET_WM_SYNC_REQUEST") &&
+	   GDK_DISPLAY_X11 (display)->use_sync)
+    {
+      GdkToplevelX11 *toplevel = _gdk_x11_window_get_toplevel (event->any.window);
+      if (toplevel)
+	{
+#ifdef HAVE_XSYNC
+	  XSyncIntsToValue (&toplevel->pending_counter_value, 
+			    xevent->xclient.data.l[2], 
+			    xevent->xclient.data.l[3]);
+#endif
+	}
+      return GDK_FILTER_REMOVE;
+    }
+  
   return GDK_FILTER_CONTINUE;
 }
 
@@ -2102,6 +2151,13 @@ _gdk_events_queue (GdkDisplay *display)
     }
 }
 
+static gboolean
+has_events_already (GdkDisplay *display)
+{
+    gboolean r = XEventsQueued (GDK_DISPLAY_XDISPLAY (display), QueuedAlready);
+    return r;
+}
+
 static gboolean  
 gdk_event_prepare (GSource  *source,
 		   gint     *timeout)
@@ -2113,7 +2169,7 @@ gdk_event_prepare (GSource  *source,
 
   *timeout = -1;
   retval = (_gdk_event_queue_find_first (display) != NULL || 
-	    gdk_check_xpending (display));
+	    has_events_already (display));
   
   GDK_THREADS_LEAVE ();
 
@@ -2150,15 +2206,15 @@ gdk_event_dispatch (GSource    *source,
   GDK_THREADS_ENTER ();
 
   _gdk_events_queue (display);
+
   event = _gdk_event_unqueue (display);
 
   if (event)
     {
       if (_gdk_event_func)
 	(*_gdk_event_func) (event, _gdk_event_data);
-      
       gdk_event_free (event);
-    }
+    }  
   
   GDK_THREADS_LEAVE ();
 
@@ -2206,7 +2262,7 @@ gdk_event_send_client_message_for_display (GdkDisplay     *display,
 
 
 /* Sends a ClientMessage to all toplevel client windows */
-gboolean
+static gboolean
 gdk_event_send_client_message_to_all_recurse (GdkDisplay *display,
 					      XEvent     *xev, 
 					      guint32     xid,
@@ -2641,6 +2697,10 @@ static struct
   { "Net/DoubleClickTime", "gtk-double-click-time" },
   { "Net/DoubleClickDistance", "gtk-double-click-distance" },
   { "Net/DndDragThreshold", "gtk-dnd-drag-threshold" },
+  { "Net/CursorBlink", "gtk-cursor-blink" },
+  { "Net/CursorBlinkTime", "gtk-cursor-blink-time" },
+  { "Net/ThemeName", "gtk-theme-name" },
+  { "Net/IconThemeName", "gtk-icon-theme-name" },
   { "Gtk/CanChangeAccels", "gtk-can-change-accels" },
   { "Gtk/ColorPalette", "gtk-color-palette" },
   { "Gtk/FontName", "gtk-font-name" },
@@ -2650,13 +2710,10 @@ static struct
   { "Gtk/ToolbarIconSize", "gtk-toolbar-icon-size" },
   { "Gtk/IMPreeditStyle", "gtk-im-preedit-style" },
   { "Gtk/IMStatusStyle", "gtk-im-status-style" },
-  { "Net/CursorBlink", "gtk-cursor-blink" },
-  { "Net/CursorBlinkTime", "gtk-cursor-blink-time" },
-  { "Net/ThemeName", "gtk-theme-name" },
-  { "Net/IconThemeName", "gtk-icon-theme-name" },
   { "Gtk/FileChooserBackend", "gtk-file-chooser-backend" },
   { "Gtk/ButtonImages", "gtk-button-images" },
   { "Gtk/MenuImages", "gtk-menu-images" },
+  { "Gtk/MenuBarAccel", "gtk-menu-bar-accel" },
   { "Xft/Antialias", "gtk-xft-antialias" },
   { "Xft/Hinting", "gtk-xft-hinting" },
   { "Xft/HintStyle", "gtk-xft-hintstyle" },
