@@ -25,6 +25,7 @@
  */
 
 #include <config.h>
+#include "gdkalias.h"
 #include "gdkinputprivate.h"
 #include "gdkinternals.h"
 #include "gdkx.h"
@@ -588,8 +589,8 @@ _gdk_input_common_other_event (GdkEvent         *event,
        * a valid timestamp.
        */
       if (gdk_event_get_time (event) != GDK_CURRENT_TIME)
-        _gdk_x11_window_set_user_time (gdk_window_get_toplevel (input_window->window),
-				       gdk_event_get_time (event));
+        gdk_x11_window_set_user_time (gdk_window_get_toplevel (input_window->window),
+                                      gdk_event_get_time (event));
       return TRUE;
   }
 
@@ -654,8 +655,8 @@ _gdk_input_common_other_event (GdkEvent         *event,
        * a valid timestamp.
        */
       if (gdk_event_get_time (event) != GDK_CURRENT_TIME)
-        _gdk_x11_window_set_user_time (gdk_window_get_toplevel (input_window->window),
-				       gdk_event_get_time (event));
+        gdk_x11_window_set_user_time (gdk_window_get_toplevel (input_window->window),
+                                      gdk_event_get_time (event));
       return TRUE;
     }
 
@@ -690,8 +691,8 @@ _gdk_input_common_other_event (GdkEvent         *event,
        * a valid timestamp.
        */
       if (gdk_event_get_time (event) != GDK_CURRENT_TIME)
-        _gdk_x11_window_set_user_time (gdk_window_get_toplevel (input_window->window),
-				       gdk_event_get_time (event));
+        gdk_x11_window_set_user_time (gdk_window_get_toplevel (input_window->window),
+                                      gdk_event_get_time (event));
       return TRUE;
     }
 
@@ -710,8 +711,8 @@ _gdk_input_common_other_event (GdkEvent         *event,
        * a valid timestamp.
        */
       if (gdk_event_get_time (event) != GDK_CURRENT_TIME)
-        _gdk_x11_window_set_user_time (gdk_window_get_toplevel (input_window->window),
-				       gdk_event_get_time (event));
+        gdk_x11_window_set_user_time (gdk_window_get_toplevel (input_window->window),
+                                      gdk_event_get_time (event));
       return TRUE;
   }
 
