@@ -24,10 +24,12 @@
  * GTK+ at ftp://ftp.gtk.org/pub/gtk/. 
  */
 
+#include <config.h>
 #include <X11/Xlib.h>
 #include <X11/Xatom.h>
 #include <string.h>
 
+#include "gdkalias.h"
 #include "gdk.h"          /* For gdk_error_trap_push/pop() */
 #include "gdkx.h"
 #include "gdkproperty.h"
@@ -505,7 +507,10 @@ gdk_property_get (GdkWindow   *window,
 
   display = gdk_drawable_get_display (window);
   xproperty = gdk_x11_atom_to_xatom_for_display (display, property);
-  xtype = gdk_x11_atom_to_xatom_for_display (display, type);
+  if (type == GDK_NONE)
+    xtype = AnyPropertyType;
+  else
+    xtype = gdk_x11_atom_to_xatom_for_display (display, type);
 
   ret_data = NULL;
   
@@ -612,7 +617,7 @@ gdk_property_change (GdkWindow    *window,
       screen = gdk_screen_get_default ();
       window = gdk_screen_get_root_window (screen);
       
-      GDK_NOTE (MULTIHEAD, g_message ("gdk_property_delete(): window is NULL\n"));
+      GDK_NOTE (MULTIHEAD, g_message ("gdk_property_change(): window is NULL\n"));
     }
 
 
