@@ -77,6 +77,7 @@ struct _GdkWindowImplX11
   GdkToplevelX11 *toplevel;	/* Toplevel-specific information */
   gint8 toplevel_window_type;
   guint override_redirect : 1;
+  guint use_synchronized_configure : 1;
 };
  
 struct _GdkWindowImplX11Class 
@@ -119,6 +120,9 @@ struct _GdkToplevelX11
   GdkPixmap *icon_window;
   GdkWindow *group_leader;
 
+  /* Time of most recent user interaction. */
+  gulong user_time;
+
   /* We use an extra X window for toplevel windows that we XSetInputFocus()
    * to in order to avoid getting keyboard events redirected to subwindows
    * that might not even be part of this app
