@@ -25,6 +25,7 @@
  */
 
 #include <config.h>
+#include "gtkalias.h"
 #include "gdkconfig.h"
 
 #include "gdk/gdkkeysyms.h"
@@ -901,7 +902,10 @@ gtk_drag_dest_set   (GtkWidget            *widget,
 
   site->flags = flags;
   site->have_drag = FALSE;
-  site->target_list = NULL;
+  if (targets)
+    site->target_list = gtk_target_list_new (targets, n_targets);
+  else
+    site->target_list = NULL;
   site->actions = actions;
   site->do_proxy = FALSE;
   site->proxy_window = NULL;
@@ -1036,10 +1040,13 @@ gtk_drag_dest_add_text_targets (GtkWidget *widget)
   GtkTargetList *target_list;
 
   target_list = gtk_drag_dest_get_target_list (widget);
-  if (!target_list)
+  if (target_list)
+    gtk_target_list_ref (target_list);
+  else
     target_list = gtk_target_list_new (NULL, 0);
   gtk_target_list_add_text_targets (target_list);
   gtk_drag_dest_set_target_list (widget, target_list);
+  gtk_target_list_unref (target_list);
 }
 
 /*************************************************************
@@ -2200,10 +2207,13 @@ gtk_drag_source_add_text_targets (GtkWidget *widget)
   GtkTargetList *target_list;
 
   target_list = gtk_drag_source_get_target_list (widget);
-  if (!target_list)
+  if (target_list)
+    gtk_target_list_ref (target_list);
+  else
     target_list = gtk_target_list_new (NULL, 0);
   gtk_target_list_add_text_targets (target_list);
   gtk_drag_source_set_target_list (widget, target_list);
+  gtk_target_list_unref (target_list);
 }
 
 static void
