@@ -20,6 +20,7 @@
 
 #include <config.h>
 
+#include "gtkalias.h"
 #include "gtkfilesystem.h"
 #include "gtkfilesystemunix.h"
 #include "gtkicontheme.h"
@@ -715,7 +716,7 @@ get_fallback_icon (GtkWidget *widget,
       break;
 
     case ICON_DIRECTORY:
-      stock_name = "gtk-directory"; /* GTK_STOCK_DIRECTORY is defined in gtkstock.h until GTK+ 2.6 */
+      stock_name = GTK_STOCK_DIRECTORY;
       break;
 
     case ICON_EXECUTABLE:
@@ -723,7 +724,7 @@ get_fallback_icon (GtkWidget *widget,
       break;
 
     default:
-      stock_name = "gtk-file"; /* GTK_STOCK_FILE is defined in gtkstock.h until GTK+ 2.6 */
+      stock_name = GTK_STOCK_FILE;
       break;
     }
 
