@@ -26,6 +26,7 @@
 
 #include <config.h>
 #include <math.h>
+#include "gtkalias.h"
 #include "gtkcontainer.h"
 #include "gtkimage.h"
 #include "gtkiconfactory.h"
@@ -33,6 +34,8 @@
 #include "gtkintl.h"
 #include <string.h>
 
+
+
 #define DEFAULT_ICON_SIZE GTK_ICON_SIZE_BUTTON
 
 static void gtk_image_class_init   (GtkImageClass  *klass);
@@ -1607,10 +1610,13 @@ gtk_image_clear (GtkImage *image)
       break;
 
     case GTK_IMAGE_ANIMATION:
-      gtk_image_reset_anim_iter (image);
+      if (image->data.anim.frame_timeout)
+        g_source_remove (image->data.anim.frame_timeout);
       
       if (image->data.anim.anim)
         g_object_unref (image->data.anim.anim);
+
+      image->data.anim.frame_timeout = 0;
       image->data.anim.anim = NULL;
       
       g_object_notify (G_OBJECT (image), "pixbuf_animation");
