@@ -43,9 +43,9 @@ struct _GtkListStore
 
   /*< private >*/
   gint stamp;
-  gpointer root;
-  gpointer tail;
-  GList *sort_list;
+  gpointer seq;		/* head of the list */
+  gpointer _gtk_reserved1;
+  GList *sort_list;	
   gint n_columns;
   gint sort_column_id;
   GtkSortType order;
