@@ -1,3 +1,4 @@
+#include "gtkalias.h"
 
 #include	<glib-object.h>
 
@@ -35,8 +36,8 @@
 #define g_marshal_value_peek_ulong(v)    (v)->data[0].v_ulong
 #define g_marshal_value_peek_int64(v)    (v)->data[0].v_int64
 #define g_marshal_value_peek_uint64(v)   (v)->data[0].v_uint64
-#define g_marshal_value_peek_enum(v)     (v)->data[0].v_int
-#define g_marshal_value_peek_flags(v)    (v)->data[0].v_uint
+#define g_marshal_value_peek_enum(v)     (v)->data[0].v_long
+#define g_marshal_value_peek_flags(v)    (v)->data[0].v_ulong
 #define g_marshal_value_peek_float(v)    (v)->data[0].v_float
 #define g_marshal_value_peek_double(v)   (v)->data[0].v_double
 #define g_marshal_value_peek_string(v)   (v)->data[0].v_pointer
@@ -711,7 +712,46 @@ _gtk_marshal_BOOLEAN__BOOLEAN_BOOLEAN_BOOLEAN (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* ENUM:ENUM (./gtkmarshalers.list:41) */
+/* BOOLEAN:STRING (./gtkmarshalers.list:41) */
+void
+_gtk_marshal_BOOLEAN__STRING (GClosure     *closure,
+                              GValue       *return_value,
+                              guint         n_param_values,
+                              const GValue *param_values,
+                              gpointer      invocation_hint,
+                              gpointer      marshal_data)
+{
+  typedef gboolean (*GMarshalFunc_BOOLEAN__STRING) (gpointer     data1,
+                                                    gpointer     arg_1,
+                                                    gpointer     data2);
+  register GMarshalFunc_BOOLEAN__STRING callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+  gboolean v_return;
+
+  g_return_if_fail (return_value != NULL);
+  g_return_if_fail (n_param_values == 2);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_BOOLEAN__STRING) (marshal_data ? marshal_data : cc->callback);
+
+  v_return = callback (data1,
+                       g_marshal_value_peek_string (param_values + 1),
+                       data2);
+
+  g_value_set_boolean (return_value, v_return);
+}
+
+/* ENUM:ENUM (./gtkmarshalers.list:42) */
 void
 _gtk_marshal_ENUM__ENUM (GClosure     *closure,
                          GValue       *return_value,
@@ -750,7 +790,7 @@ _gtk_marshal_ENUM__ENUM (GClosure     *closure,
   g_value_set_enum (return_value, v_return);
 }
 
-/* INT:POINTER (./gtkmarshalers.list:42) */
+/* INT:POINTER (./gtkmarshalers.list:43) */
 void
 _gtk_marshal_INT__POINTER (GClosure     *closure,
                            GValue       *return_value,
@@ -789,13 +829,13 @@ _gtk_marshal_INT__POINTER (GClosure     *closure,
   g_value_set_int (return_value, v_return);
 }
 
-/* NONE:BOOLEAN (./gtkmarshalers.list:43) */
+/* NONE:BOOLEAN (./gtkmarshalers.list:44) */
 
-/* NONE:ENUM (./gtkmarshalers.list:44) */
+/* NONE:ENUM (./gtkmarshalers.list:45) */
 
-/* NONE:INT (./gtkmarshalers.list:45) */
+/* NONE:INT (./gtkmarshalers.list:46) */
 
-/* NONE:INT,BOOL (./gtkmarshalers.list:46) */
+/* NONE:INT,BOOL (./gtkmarshalers.list:47) */
 void
 _gtk_marshal_VOID__INT_BOOLEAN (GClosure     *closure,
                                 GValue       *return_value,
@@ -832,7 +872,7 @@ _gtk_marshal_VOID__INT_BOOLEAN (GClosure     *closure,
             data2);
 }
 
-/* NONE:INT,INT (./gtkmarshalers.list:47) */
+/* NONE:INT,INT (./gtkmarshalers.list:48) */
 void
 _gtk_marshal_VOID__INT_INT (GClosure     *closure,
                             GValue       *return_value,
@@ -869,9 +909,9 @@ _gtk_marshal_VOID__INT_INT (GClosure     *closure,
             data2);
 }
 
-/* NONE:NONE (./gtkmarshalers.list:48) */
+/* NONE:NONE (./gtkmarshalers.list:49) */
 
-/* NONE:STRING,INT,POINTER (./gtkmarshalers.list:49) */
+/* NONE:STRING,INT,POINTER (./gtkmarshalers.list:50) */
 void
 _gtk_marshal_VOID__STRING_INT_POINTER (GClosure     *closure,
                                        GValue       *return_value,
@@ -910,7 +950,7 @@ _gtk_marshal_VOID__STRING_INT_POINTER (GClosure     *closure,
             data2);
 }
 
-/* STRING:DOUBLE (./gtkmarshalers.list:50) */
+/* STRING:DOUBLE (./gtkmarshalers.list:51) */
 void
 _gtk_marshal_STRING__DOUBLE (GClosure     *closure,
                              GValue       *return_value,
@@ -949,11 +989,11 @@ _gtk_marshal_STRING__DOUBLE (GClosure     *closure,
   g_value_take_string (return_value, v_return);
 }
 
-/* VOID:DOUBLE (./gtkmarshalers.list:51) */
+/* VOID:DOUBLE (./gtkmarshalers.list:52) */
 
-/* VOID:BOOLEAN (./gtkmarshalers.list:52) */
+/* VOID:BOOLEAN (./gtkmarshalers.list:53) */
 
-/* VOID:BOOLEAN,BOOLEAN,BOOLEAN (./gtkmarshalers.list:53) */
+/* VOID:BOOLEAN,BOOLEAN,BOOLEAN (./gtkmarshalers.list:54) */
 void
 _gtk_marshal_VOID__BOOLEAN_BOOLEAN_BOOLEAN (GClosure     *closure,
                                             GValue       *return_value,
@@ -992,9 +1032,9 @@ _gtk_marshal_VOID__BOOLEAN_BOOLEAN_BOOLEAN (GClosure     *closure,
             data2);
 }
 
-/* VOID:BOXED (./gtkmarshalers.list:54) */
+/* VOID:BOXED (./gtkmarshalers.list:55) */
 
-/* VOID:BOXED,BOXED (./gtkmarshalers.list:55) */
+/* VOID:BOXED,BOXED (./gtkmarshalers.list:56) */
 void
 _gtk_marshal_VOID__BOXED_BOXED (GClosure     *closure,
                                 GValue       *return_value,
@@ -1031,7 +1071,7 @@ _gtk_marshal_VOID__BOXED_BOXED (GClosure     *closure,
             data2);
 }
 
-/* VOID:BOXED,BOXED,POINTER (./gtkmarshalers.list:56) */
+/* VOID:BOXED,BOXED,POINTER (./gtkmarshalers.list:57) */
 void
 _gtk_marshal_VOID__BOXED_BOXED_POINTER (GClosure     *closure,
                                         GValue       *return_value,
@@ -1070,7 +1110,7 @@ _gtk_marshal_VOID__BOXED_BOXED_POINTER (GClosure     *closure,
             data2);
 }
 
-/* VOID:BOXED,OBJECT (./gtkmarshalers.list:57) */
+/* VOID:BOXED,OBJECT (./gtkmarshalers.list:58) */
 void
 _gtk_marshal_VOID__BOXED_OBJECT (GClosure     *closure,
                                  GValue       *return_value,
@@ -1107,7 +1147,7 @@ _gtk_marshal_VOID__BOXED_OBJECT (GClosure     *closure,
             data2);
 }
 
-/* VOID:BOXED,STRING,INT (./gtkmarshalers.list:58) */
+/* VOID:BOXED,STRING,INT (./gtkmarshalers.list:59) */
 void
 _gtk_marshal_VOID__BOXED_STRING_INT (GClosure     *closure,
                                      GValue       *return_value,
@@ -1146,7 +1186,7 @@ _gtk_marshal_VOID__BOXED_STRING_INT (GClosure     *closure,
             data2);
 }
 
-/* VOID:BOXED,UINT (./gtkmarshalers.list:59) */
+/* VOID:BOXED,UINT (./gtkmarshalers.list:60) */
 void
 _gtk_marshal_VOID__BOXED_UINT (GClosure     *closure,
                                GValue       *return_value,
@@ -1183,7 +1223,7 @@ _gtk_marshal_VOID__BOXED_UINT (GClosure     *closure,
             data2);
 }
 
-/* VOID:BOXED,UINT,FLAGS (./gtkmarshalers.list:60) */
+/* VOID:BOXED,UINT,FLAGS (./gtkmarshalers.list:61) */
 void
 _gtk_marshal_VOID__BOXED_UINT_FLAGS (GClosure     *closure,
                                      GValue       *return_value,
@@ -1222,7 +1262,7 @@ _gtk_marshal_VOID__BOXED_UINT_FLAGS (GClosure     *closure,
             data2);
 }
 
-/* VOID:BOXED,UINT,UINT (./gtkmarshalers.list:61) */
+/* VOID:BOXED,UINT,UINT (./gtkmarshalers.list:62) */
 void
 _gtk_marshal_VOID__BOXED_UINT_UINT (GClosure     *closure,
                                     GValue       *return_value,
@@ -1261,9 +1301,9 @@ _gtk_marshal_VOID__BOXED_UINT_UINT (GClosure     *closure,
             data2);
 }
 
-/* VOID:ENUM (./gtkmarshalers.list:62) */
+/* VOID:ENUM (./gtkmarshalers.list:63) */
 
-/* VOID:ENUM,BOOLEAN (./gtkmarshalers.list:63) */
+/* VOID:ENUM,BOOLEAN (./gtkmarshalers.list:64) */
 void
 _gtk_marshal_VOID__ENUM_BOOLEAN (GClosure     *closure,
                                  GValue       *return_value,
@@ -1300,7 +1340,7 @@ _gtk_marshal_VOID__ENUM_BOOLEAN (GClosure     *closure,
             data2);
 }
 
-/* VOID:ENUM,ENUM (./gtkmarshalers.list:64) */
+/* VOID:ENUM,ENUM (./gtkmarshalers.list:65) */
 void
 _gtk_marshal_VOID__ENUM_ENUM (GClosure     *closure,
                               GValue       *return_value,
@@ -1337,7 +1377,7 @@ _gtk_marshal_VOID__ENUM_ENUM (GClosure     *closure,
             data2);
 }
 
-/* VOID:ENUM,FLOAT (./gtkmarshalers.list:65) */
+/* VOID:ENUM,FLOAT (./gtkmarshalers.list:66) */
 void
 _gtk_marshal_VOID__ENUM_FLOAT (GClosure     *closure,
                                GValue       *return_value,
@@ -1374,7 +1414,7 @@ _gtk_marshal_VOID__ENUM_FLOAT (GClosure     *closure,
             data2);
 }
 
-/* VOID:ENUM,FLOAT,BOOLEAN (./gtkmarshalers.list:66) */
+/* VOID:ENUM,FLOAT,BOOLEAN (./gtkmarshalers.list:67) */
 void
 _gtk_marshal_VOID__ENUM_FLOAT_BOOLEAN (GClosure     *closure,
                                        GValue       *return_value,
@@ -1413,7 +1453,7 @@ _gtk_marshal_VOID__ENUM_FLOAT_BOOLEAN (GClosure     *closure,
             data2);
 }
 
-/* VOID:ENUM,INT (./gtkmarshalers.list:67) */
+/* VOID:ENUM,INT (./gtkmarshalers.list:68) */
 void
 _gtk_marshal_VOID__ENUM_INT (GClosure     *closure,
                              GValue       *return_value,
@@ -1450,7 +1490,7 @@ _gtk_marshal_VOID__ENUM_INT (GClosure     *closure,
             data2);
 }
 
-/* VOID:ENUM,INT,BOOLEAN (./gtkmarshalers.list:68) */
+/* VOID:ENUM,INT,BOOLEAN (./gtkmarshalers.list:69) */
 void
 _gtk_marshal_VOID__ENUM_INT_BOOLEAN (GClosure     *closure,
                                      GValue       *return_value,
@@ -1489,11 +1529,11 @@ _gtk_marshal_VOID__ENUM_INT_BOOLEAN (GClosure     *closure,
             data2);
 }
 
-/* VOID:INT (./gtkmarshalers.list:69) */
+/* VOID:INT (./gtkmarshalers.list:70) */
 
-/* VOID:INT,INT (./gtkmarshalers.list:70) */
+/* VOID:INT,INT (./gtkmarshalers.list:71) */
 
-/* VOID:INT,INT,BOXED (./gtkmarshalers.list:71) */
+/* VOID:INT,INT,BOXED (./gtkmarshalers.list:72) */
 void
 _gtk_marshal_VOID__INT_INT_BOXED (GClosure     *closure,
                                   GValue       *return_value,
@@ -1532,7 +1572,7 @@ _gtk_marshal_VOID__INT_INT_BOXED (GClosure     *closure,
             data2);
 }
 
-/* VOID:INT,INT,INT (./gtkmarshalers.list:72) */
+/* VOID:INT,INT,INT (./gtkmarshalers.list:73) */
 void
 _gtk_marshal_VOID__INT_INT_INT (GClosure     *closure,
                                 GValue       *return_value,
@@ -1571,9 +1611,9 @@ _gtk_marshal_VOID__INT_INT_INT (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT (./gtkmarshalers.list:73) */
+/* VOID:OBJECT (./gtkmarshalers.list:74) */
 
-/* VOID:OBJECT,BOOLEAN (./gtkmarshalers.list:74) */
+/* VOID:OBJECT,BOOLEAN (./gtkmarshalers.list:75) */
 void
 _gtk_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
                                    GValue       *return_value,
@@ -1610,7 +1650,7 @@ _gtk_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,BOXED,BOXED (./gtkmarshalers.list:75) */
+/* VOID:OBJECT,BOXED,BOXED (./gtkmarshalers.list:76) */
 void
 _gtk_marshal_VOID__OBJECT_BOXED_BOXED (GClosure     *closure,
                                        GValue       *return_value,
@@ -1649,7 +1689,7 @@ _gtk_marshal_VOID__OBJECT_BOXED_BOXED (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,BOXED,UINT,UINT (./gtkmarshalers.list:76) */
+/* VOID:OBJECT,BOXED,UINT,UINT (./gtkmarshalers.list:77) */
 void
 _gtk_marshal_VOID__OBJECT_BOXED_UINT_UINT (GClosure     *closure,
                                            GValue       *return_value,
@@ -1690,7 +1730,7 @@ _gtk_marshal_VOID__OBJECT_BOXED_UINT_UINT (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,INT,INT (./gtkmarshalers.list:77) */
+/* VOID:OBJECT,INT,INT (./gtkmarshalers.list:78) */
 void
 _gtk_marshal_VOID__OBJECT_INT_INT (GClosure     *closure,
                                    GValue       *return_value,
@@ -1729,7 +1769,7 @@ _gtk_marshal_VOID__OBJECT_INT_INT (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,INT,INT,BOXED,UINT,UINT (./gtkmarshalers.list:78) */
+/* VOID:OBJECT,INT,INT,BOXED,UINT,UINT (./gtkmarshalers.list:79) */
 void
 _gtk_marshal_VOID__OBJECT_INT_INT_BOXED_UINT_UINT (GClosure     *closure,
                                                    GValue       *return_value,
@@ -1774,7 +1814,7 @@ _gtk_marshal_VOID__OBJECT_INT_INT_BOXED_UINT_UINT (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,OBJECT (./gtkmarshalers.list:79) */
+/* VOID:OBJECT,OBJECT (./gtkmarshalers.list:80) */
 void
 _gtk_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                   GValue       *return_value,
@@ -1811,7 +1851,44 @@ _gtk_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,STRING,STRING (./gtkmarshalers.list:80) */
+/* VOID:OBJECT,STRING (./gtkmarshalers.list:81) */
+void
+_gtk_marshal_VOID__OBJECT_STRING (GClosure     *closure,
+                                  GValue       *return_value,
+                                  guint         n_param_values,
+                                  const GValue *param_values,
+                                  gpointer      invocation_hint,
+                                  gpointer      marshal_data)
+{
+  typedef void (*GMarshalFunc_VOID__OBJECT_STRING) (gpointer     data1,
+                                                    gpointer     arg_1,
+                                                    gpointer     arg_2,
+                                                    gpointer     data2);
+  register GMarshalFunc_VOID__OBJECT_STRING callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+
+  g_return_if_fail (n_param_values == 3);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_VOID__OBJECT_STRING) (marshal_data ? marshal_data : cc->callback);
+
+  callback (data1,
+            g_marshal_value_peek_object (param_values + 1),
+            g_marshal_value_peek_string (param_values + 2),
+            data2);
+}
+
+/* VOID:OBJECT,STRING,STRING (./gtkmarshalers.list:82) */
 void
 _gtk_marshal_VOID__OBJECT_STRING_STRING (GClosure     *closure,
                                          GValue       *return_value,
@@ -1850,7 +1927,7 @@ _gtk_marshal_VOID__OBJECT_STRING_STRING (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,UINT (./gtkmarshalers.list:81) */
+/* VOID:OBJECT,UINT (./gtkmarshalers.list:83) */
 void
 _gtk_marshal_VOID__OBJECT_UINT (GClosure     *closure,
                                 GValue       *return_value,
@@ -1887,7 +1964,7 @@ _gtk_marshal_VOID__OBJECT_UINT (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,UINT,FLAGS (./gtkmarshalers.list:82) */
+/* VOID:OBJECT,UINT,FLAGS (./gtkmarshalers.list:84) */
 void
 _gtk_marshal_VOID__OBJECT_UINT_FLAGS (GClosure     *closure,
                                       GValue       *return_value,
@@ -1926,9 +2003,11 @@ _gtk_marshal_VOID__OBJECT_UINT_FLAGS (GClosure     *closure,
             data2);
 }
 
-/* VOID:POINTER (./gtkmarshalers.list:83) */
+/* VOID:OBJECT,STRING (./gtkmarshalers.list:85) */
 
-/* VOID:POINTER,INT (./gtkmarshalers.list:84) */
+/* VOID:POINTER (./gtkmarshalers.list:86) */
+
+/* VOID:POINTER,INT (./gtkmarshalers.list:87) */
 void
 _gtk_marshal_VOID__POINTER_INT (GClosure     *closure,
                                 GValue       *return_value,
@@ -1965,7 +2044,7 @@ _gtk_marshal_VOID__POINTER_INT (GClosure     *closure,
             data2);
 }
 
-/* VOID:POINTER,BOOLEAN (./gtkmarshalers.list:85) */
+/* VOID:POINTER,BOOLEAN (./gtkmarshalers.list:88) */
 void
 _gtk_marshal_VOID__POINTER_BOOLEAN (GClosure     *closure,
                                     GValue       *return_value,
@@ -2002,7 +2081,7 @@ _gtk_marshal_VOID__POINTER_BOOLEAN (GClosure     *closure,
             data2);
 }
 
-/* VOID:POINTER,POINTER,POINTER (./gtkmarshalers.list:86) */
+/* VOID:POINTER,POINTER,POINTER (./gtkmarshalers.list:89) */
 void
 _gtk_marshal_VOID__POINTER_POINTER_POINTER (GClosure     *closure,
                                             GValue       *return_value,
@@ -2041,7 +2120,7 @@ _gtk_marshal_VOID__POINTER_POINTER_POINTER (GClosure     *closure,
             data2);
 }
 
-/* VOID:POINTER,UINT (./gtkmarshalers.list:87) */
+/* VOID:POINTER,UINT (./gtkmarshalers.list:90) */
 void
 _gtk_marshal_VOID__POINTER_UINT (GClosure     *closure,
                                  GValue       *return_value,
@@ -2078,9 +2157,9 @@ _gtk_marshal_VOID__POINTER_UINT (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING (./gtkmarshalers.list:88) */
+/* VOID:STRING (./gtkmarshalers.list:91) */
 
-/* VOID:STRING,STRING (./gtkmarshalers.list:89) */
+/* VOID:STRING,STRING (./gtkmarshalers.list:92) */
 void
 _gtk_marshal_VOID__STRING_STRING (GClosure     *closure,
                                   GValue       *return_value,
@@ -2117,9 +2196,9 @@ _gtk_marshal_VOID__STRING_STRING (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,INT,POINTER (./gtkmarshalers.list:90) */
+/* VOID:STRING,INT,POINTER (./gtkmarshalers.list:93) */
 
-/* VOID:STRING,UINT,FLAGS (./gtkmarshalers.list:91) */
+/* VOID:STRING,UINT,FLAGS (./gtkmarshalers.list:94) */
 void
 _gtk_marshal_VOID__STRING_UINT_FLAGS (GClosure     *closure,
                                       GValue       *return_value,
@@ -2158,7 +2237,7 @@ _gtk_marshal_VOID__STRING_UINT_FLAGS (GClosure     *closure,
             data2);
 }
 
-/* VOID:UINT,FLAGS,BOXED (./gtkmarshalers.list:92) */
+/* VOID:UINT,FLAGS,BOXED (./gtkmarshalers.list:95) */
 void
 _gtk_marshal_VOID__UINT_FLAGS_BOXED (GClosure     *closure,
                                      GValue       *return_value,
@@ -2197,7 +2276,7 @@ _gtk_marshal_VOID__UINT_FLAGS_BOXED (GClosure     *closure,
             data2);
 }
 
-/* VOID:UINT,UINT (./gtkmarshalers.list:93) */
+/* VOID:UINT,UINT (./gtkmarshalers.list:96) */
 void
 _gtk_marshal_VOID__UINT_UINT (GClosure     *closure,
                               GValue       *return_value,
@@ -2234,7 +2313,7 @@ _gtk_marshal_VOID__UINT_UINT (GClosure     *closure,
             data2);
 }
 
-/* VOID:UINT,STRING (./gtkmarshalers.list:94) */
+/* VOID:UINT,STRING (./gtkmarshalers.list:97) */
 void
 _gtk_marshal_VOID__UINT_STRING (GClosure     *closure,
                                 GValue       *return_value,
@@ -2271,7 +2350,7 @@ _gtk_marshal_VOID__UINT_STRING (GClosure     *closure,
             data2);
 }
 
-/* VOID:UINT,BOXED,UINT,FLAGS,FLAGS (./gtkmarshalers.list:95) */
+/* VOID:UINT,BOXED,UINT,FLAGS,FLAGS (./gtkmarshalers.list:98) */
 void
 _gtk_marshal_VOID__UINT_BOXED_UINT_FLAGS_FLAGS (GClosure     *closure,
                                                 GValue       *return_value,
@@ -2314,7 +2393,7 @@ _gtk_marshal_VOID__UINT_BOXED_UINT_FLAGS_FLAGS (GClosure     *closure,
             data2);
 }
 
-/* VOID:UINT,OBJECT,UINT,FLAGS,FLAGS (./gtkmarshalers.list:96) */
+/* VOID:UINT,OBJECT,UINT,FLAGS,FLAGS (./gtkmarshalers.list:99) */
 void
 _gtk_marshal_VOID__UINT_OBJECT_UINT_FLAGS_FLAGS (GClosure     *closure,
                                                  GValue       *return_value,
@@ -2357,5 +2436,5 @@ _gtk_marshal_VOID__UINT_OBJECT_UINT_FLAGS_FLAGS (GClosure     *closure,
             data2);
 }
 
-/* VOID:VOID (./gtkmarshalers.list:97) */
+/* VOID:VOID (./gtkmarshalers.list:100) */
 
