@@ -24,9 +24,11 @@
  * GTK+ at ftp://ftp.gtk.org/pub/gtk/. 
  */
 
+#include <config.h>
 #include <glib/gprintf.h>
 #include <math.h>
 #include <string.h>
+#include "gtkalias.h"
 #include "gtkprogress.h" 
 #include "gtkintl.h"
 
