@@ -16,6 +16,8 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#include <config.h>
+#include "gtkalias.h"
 #include "gtksettings.h"
 #include "gtkrc.h"
 #include "gtkintl.h"
@@ -43,7 +45,6 @@ struct _GtkSettingsPropertyValue
 };
 
 #ifdef GDK_WINDOWING_X11
-#include <X11/Xft/Xft.h>
 #include <pango/pangoxft.h>
 #include <gdk/x11/gdkx.h>
 #endif
@@ -312,7 +313,8 @@ gtk_settings_class_init (GtkSettingsClass *class)
 								  "hicolor",
 								  G_PARAM_READWRITE),
                                              NULL);
-  g_assert (result == PROP_ICON_THEME_NAME);    
+  g_assert (result == PROP_ICON_THEME_NAME);
+  
   result = settings_install_property_parser (class,
                                              g_param_spec_string ("gtk-key-theme-name",
 								  P_("Key Theme Name"),
@@ -594,9 +596,11 @@ gtk_settings_notify (GObject    *object,
     case PROP_XFT_DPI:
       pango_xft_substitute_changed (GDK_SCREEN_XDISPLAY (settings->screen),
  				    GDK_SCREEN_XNUMBER (settings->screen));
-      /* See comments with _gtk_rc_reset_styles for why this is a hack
+      /* This is a hack because with gtk_rc_reset_styles() doesn't get
+       * widgets with gtk_widget_style_set(), and also causes more
+       * recomputation than necessary.
        */
-      _gtk_rc_reset_styles (GTK_SETTINGS (object));
+      gtk_rc_reset_styles (GTK_SETTINGS (object));
       break;
 #endif /* GDK_WINDOWING_X11 */
     }
@@ -681,8 +685,11 @@ apply_queued_setting (GtkSettings             *data,
   if (_gtk_settings_parse_convert (parser, &qvalue->public.value,
 				   pspec, &tmp_value))
     {
-      g_object_set_property (G_OBJECT (data), pspec->name, &tmp_value);
-      data->property_values[pspec->param_id - 1].source = qvalue->source;
+      if (data->property_values[pspec->param_id - 1].source <= qvalue->source)
+	{
+	  g_object_set_property (G_OBJECT (data), pspec->name, &tmp_value);
+	  data->property_values[pspec->param_id - 1].source = qvalue->source;
+	}
     }
   else
     {
