@@ -20,6 +20,8 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#include <config.h>
+#include "gtkalias.h"
 #include "gtktoolbutton.h"
 #include "gtkbutton.h"
 #include "gtkhbox.h"
@@ -48,7 +50,7 @@ enum {
   PROP_USE_UNDERLINE,
   PROP_LABEL_WIDGET,
   PROP_STOCK_ID,
-  PROP_ICON_WIDGET,
+  PROP_ICON_WIDGET
 };
 
 static void gtk_tool_button_init          (GtkToolButton      *button,
@@ -387,7 +389,8 @@ gtk_tool_button_construct_contents (GtkToolItem *tool_item)
 
     case GTK_TOOLBAR_BOTH_HORIZ:
       box = gtk_hbox_new (FALSE, 0);
-      gtk_box_pack_start (GTK_BOX (box), icon, label? FALSE : TRUE, TRUE, 0);
+      if (icon)
+	gtk_box_pack_start (GTK_BOX (box), icon, label? FALSE : TRUE, TRUE, 0);
       if (label)
 	gtk_box_pack_start (GTK_BOX (box), label, TRUE, TRUE, 0);
       gtk_container_add (GTK_CONTAINER (button->priv->button), box);
@@ -441,8 +444,11 @@ static void
 gtk_tool_button_property_notify (GObject          *object,
 				 GParamSpec       *pspec)
 {
-  if (strcmp (pspec->name, "is_important"))
+  if (strcmp (pspec->name, "is-important") == 0)
     gtk_tool_button_construct_contents (GTK_TOOL_ITEM (object));
+
+  if (parent_class->notify)
+    parent_class->notify (object, pspec);
 }
 
 static void
@@ -837,8 +843,16 @@ gtk_tool_button_set_icon_widget (GtkToolButton *button,
   if (icon_widget != button->priv->icon_widget)
     {
       if (button->priv->icon_widget)
-	g_object_unref (G_OBJECT (button->priv->icon_widget));
+	{
+	  if (button->priv->icon_widget->parent)
+	    {
+	      gtk_container_remove (GTK_CONTAINER (button->priv->icon_widget->parent),
+				    button->priv->icon_widget);
+	    }
 
+	  g_object_unref (G_OBJECT (button->priv->icon_widget));
+	}
+      
       if (icon_widget)
 	{
 	  g_object_ref (icon_widget);
@@ -876,8 +890,16 @@ gtk_tool_button_set_label_widget (GtkToolButton *button,
   if (label_widget != button->priv->label_widget)
     {
       if (button->priv->label_widget)
-	g_object_unref (button->priv->label_widget);
-
+	{
+	  if (button->priv->label_widget->parent)
+	    {
+	      gtk_container_remove (GTK_CONTAINER (button->priv->label_widget->parent),
+				    button->priv->label_widget);
+	    }
+	  
+	  g_object_unref (button->priv->label_widget);
+	}
+      
       if (label_widget)
 	{
 	  g_object_ref (label_widget);
