@@ -18,7 +18,7 @@
  */
 
 #include <config.h>
-#include <string.h>
+#include "gtkalias.h"
 #include "gtktreeselection.h"
 #include "gtktreeprivate.h"
 #include "gtkrbtree.h"
@@ -364,10 +364,6 @@ gtk_tree_selection_get_selected (GtkTreeSelection  *selection,
   g_return_val_if_fail (selection->type != GTK_SELECTION_MULTIPLE, FALSE);
   g_return_val_if_fail (selection->tree_view != NULL, FALSE);
 
-  /* Clear the iter */
-  if (iter)
-    memset (iter, 0, sizeof (GtkTreeIter));
-
   if (model)
     *model = selection->tree_view->priv->model;
 
@@ -1024,7 +1020,7 @@ gtk_tree_selection_real_select_all (GtkTreeSelection *selection)
  * gtk_tree_selection_select_all:
  * @selection: A #GtkTreeSelection.
  *
- * Selects all the nodes.  @selection is must be set to #GTK_SELECTION_MULTIPLE
+ * Selects all the nodes. @selection must be set to #GTK_SELECTION_MULTIPLE
  * mode.
  **/
 void
@@ -1286,6 +1282,81 @@ gtk_tree_selection_unselect_range (GtkTreeSelection *selection,
     g_signal_emit (selection, tree_selection_signals[CHANGED], 0);
 }
 
+static gboolean
+tree_column_is_sensitive (GtkTreeViewColumn *column,
+			  GtkTreeModel      *model,
+			  GtkTreeIter       *iter)
+{
+  GList *cells, *list;
+  gboolean sensitive;
+  gboolean visible;
+
+  gtk_tree_view_column_cell_set_cell_data (column, model,
+					   iter, FALSE, FALSE);
+
+  cells = gtk_tree_view_column_get_cell_renderers (column);
+
+  list = cells;
+  while (list)
+    {
+      g_object_get (G_OBJECT (list->data), 
+		    "sensitive", &sensitive, 
+		    "visible", &visible,
+		    NULL);
+      
+      if (visible && sensitive)
+	break;
+
+      list = list->next;
+    }
+  g_list_free (cells);
+
+  return sensitive;
+}
+
+static gboolean
+row_is_selectable (GtkTreeSelection *selection,
+		   GtkRBNode        *node,
+		   GtkTreePath      *path)
+{
+  GList *list;
+  GtkTreeIter iter;
+  gboolean sensitive = FALSE;
+
+  if (!gtk_tree_model_get_iter (selection->tree_view->priv->model, &iter, path))
+    sensitive = TRUE;
+
+  if (!sensitive && selection->tree_view->priv->row_separator_func)
+    {
+      /* never allow separators to be selected */
+      if ((* selection->tree_view->priv->row_separator_func) (selection->tree_view->priv->model,
+							      &iter,
+							      selection->tree_view->priv->row_separator_data))
+	return FALSE;
+    }
+
+  for (list = selection->tree_view->priv->columns; list && !sensitive; list = list->next)
+    {
+      GtkTreeViewColumn *column = GTK_TREE_VIEW_COLUMN (list->data);
+
+      if (!column->visible)
+	continue;
+
+      sensitive = tree_column_is_sensitive (column, selection->tree_view->priv->model, &iter);
+    }
+
+  if (!sensitive)
+    return FALSE;
+
+  if (selection->user_func)
+    return (*selection->user_func) (selection, selection->tree_view->priv->model, path,
+				    GTK_RBNODE_FLAG_SET (node, GTK_RBNODE_IS_SELECTED),
+				    selection->user_data);
+  else
+    return TRUE;
+}
+
+
 /* Called internally by gtktreeview.c It handles actually selecting the tree.
  */
 
@@ -1335,17 +1406,7 @@ _gtk_tree_selection_internal_select_node (GtkTreeSelection *selection,
 	    {
 	      /* We only want to select the new node if we can unselect the old one,
 	       * and we can select the new one. */
-	      if (selection->user_func)
-		{
-		  if ((*selection->user_func) (selection, selection->tree_view->priv->model, path,
-					       GTK_RBNODE_FLAG_SET (node, GTK_RBNODE_IS_SELECTED),
-					       selection->user_data))
-		    dirty = TRUE;
-		}
-	      else
-		{
-		  dirty = TRUE;
-		}
+	      dirty = row_is_selectable (selection, node, path);
 
 	      /* if dirty is FALSE, we weren't able to select the new one, otherwise, we try to
 	       * unselect the new one
@@ -1462,15 +1523,7 @@ gtk_tree_selection_real_select_node (GtkTreeSelection *selection,
   if (GTK_RBNODE_FLAG_SET (node, GTK_RBNODE_IS_SELECTED) != select)
     {
       path = _gtk_tree_view_find_path (selection->tree_view, tree, node);
-      if (selection->user_func)
-	{
-	  if ((*selection->user_func) (selection, selection->tree_view->priv->model, path,
-                                       GTK_RBNODE_FLAG_SET (node, GTK_RBNODE_IS_SELECTED),
-                                       selection->user_data))
-	    selected = TRUE;
-	}
-      else
-	selected = TRUE;
+      selected = row_is_selectable (selection, node, path);
       gtk_tree_path_free (path);
     }
 
