@@ -31,6 +31,7 @@
 #include <config.h>
 
 #include <string.h>
+#include "gtkalias.h"
 #include "gtkintl.h"
 #include "gtkmarshalers.h"
 #include "gtkmenu.h"
@@ -271,7 +272,7 @@ gtk_ui_manager_class_init (GtkUIManagerClass *klass)
 		  G_TYPE_NONE, 0);
   
   /**
-   * GtkUIManager::connect_proxy:
+   * GtkUIManager::connect-proxy:
    * @uimanager: the ui manager
    * @action: the action
    * @proxy: the proxy
@@ -297,7 +298,7 @@ gtk_ui_manager_class_init (GtkUIManagerClass *klass)
 		  GTK_TYPE_WIDGET);
 
   /**
-   * GtkUIManager::disconnect_proxy:
+   * GtkUIManager::disconnect-proxy:
    * @uimanager: the ui manager
    * @action: the action
    * @proxy: the proxy
@@ -319,7 +320,7 @@ gtk_ui_manager_class_init (GtkUIManagerClass *klass)
 		  GTK_TYPE_WIDGET);
 
   /**
-   * GtkUIManager::pre_activate:
+   * GtkUIManager::pre-activate:
    * @uimanager: the ui manager
    * @action: the action
    *
@@ -342,7 +343,7 @@ gtk_ui_manager_class_init (GtkUIManagerClass *klass)
 		  GTK_TYPE_ACTION);
 
   /**
-   * GtkUIManager::post_activate:
+   * GtkUIManager::post-activate:
    * @uimanager: the ui manager
    * @action: the action
    *
@@ -711,8 +712,6 @@ gtk_ui_manager_get_widget (GtkUIManager *self,
    * widget */
   gtk_ui_manager_ensure_update (self);
 
-  if (strncmp ("/ui", path, 3) == 0)
-    path += 3;
   node = get_node (self, path, NODE_TYPE_UNDECIDED, FALSE);
 
   if (node == NULL)
@@ -915,6 +914,9 @@ get_node (GtkUIManager *self,
   const gchar *pos, *end;
   GNode *parent, *node;
   
+  if (strncmp ("/ui", path, 3) == 0)
+    path += 3;
+  
   end = path + strlen (path);
   pos = path;
   parent = node = NULL;
